@@ -2,7 +2,7 @@
  * sxid - suid, sgid file and directory checking
  * conffile.c - configuration file functions
  *
- * Copyright (C) 1999 Ben Collins <bcollins@debian.org>
+ * Copyright (C) 1999, 2000, 2002 Ben Collins <bcollins@debian.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -25,19 +25,15 @@
 #include <unistd.h>
 #include <errno.h>
 #include <ctype.h>
-#include <strings.h>
 
-#include "config.h"
-#include "structs.h"
-#include "globals.h"
-#include "conffile.h"
+#include "sxid.h"
 
 struct config_opt config_options;
 static char conf_default[] = CONF_FILE;
 char *confname = conf_default;
 
 static
-int get_value (char *key, char *value)
+void get_value (char *key, char *value, int required)
 {
     FILE *conffile;
     char buffer[MAXBUF];
@@ -47,14 +43,16 @@ int get_value (char *key, char *value)
     bzero (buffer, sizeof (buffer));
 
     if ((conffile = fopen (confname, "r")) == NULL) {
-	return 1;
+	fprintf (stderr, "E: error opening config file, %s.\n", confname);
+	exit (1);
     } else {
 	while ((fgets (buffer, sizeof (buffer), conffile)) != NULL) {
 	    if (buffer[0] != '#') {
 		if (strstr (buffer, key) != (char) NULL) {
 		    if (strstr (buffer, "\"") == (char) NULL) {
+			fprintf (stderr, "E: in \'%s\', line %d.\n", confname, line_no);
 			fclose (conffile);
-			return line_no;
+			exit (1);
 		    }
 		    strncpy (buffer, strstr (buffer, "\"") + 1, MAXBUF);
 		    buffer[MAXBUF - 1] = '\0';
@@ -71,33 +69,19 @@ int get_value (char *key, char *value)
 		    }
 		    value[sizeof (buffer) - 1] = '\0';
 		    fclose (conffile);
-		    return 0;
+		    return;
 		}
 	    }
 	    line_no++;
 	}
 	fclose (conffile);
-	return -1;
-    }
-}
-
-static
-void check_return (int line, char *key, int required)
-{
-    if (!line)
-	return;
-    switch (line) {
-    case -1:
 	if (required) {
-	    fprintf (stderr, "E: option \'%s\' not found in \'%s\'.\n",
+	    fprintf (stderr, "E: required option \'%s\' not found in \'%s\'.\n",
 		key, confname);
-	    break;
-	} else
-	    return;
-    default:
-	fprintf (stderr, "E: in \'%s\', line %d.\n", confname, line);
+	    exit (1);
+	}
+	return;
     }
-    exit (1);
 }
 
 void init_conf (void)
@@ -109,41 +93,43 @@ void init_conf (void)
     strcpy ((char *) config_options.email, "root");
     strcpy ((char *) config_options.forbidden_paths, "");
     strcpy ((char *) config_options.ignore_dirs, "");
+    config_options.extra_list[0] = '\0';
     strcpy ((char *) config_options.mail_prog, MAIL_PROG);
     config_options.keep_logs = 3;
 
     if (config_options.flags & FLAG_SPOT) {
 	if(getcwd(config_options.search_paths, MAXBUF) == NULL) {
 	    fprintf(stderr, "E: current working directory path is too long\n");
-	    exit(1);
+	    exit (1);
 	}
 	nomail = 1;
     } else
-	check_return (get_value ("SEARCH", config_options.search_paths), "SEARCH", 1);
+	get_value ("SEARCH", config_options.search_paths, 1);
 
-    check_return (get_value ("EMAIL", config_options.email), "EMAIL", 0);
-    check_return (get_value ("EXCLUDE", config_options.exclude_paths), "EXCLUDE", 0);
-    check_return (get_value ("IGNORE_DIRS", config_options.ignore_dirs), "IGNORE_DIRS", 0);
-    check_return (get_value ("LOG_FILE", config_options.log_file), "LOG_FILE", 1);
-    check_return (get_value ("MAIL_PROG", config_options.mail_prog), "MAIL_PROG", 0);
-    check_return (get_value ("FORBIDDEN", config_options.forbidden_paths), "FORBIDDEN", 0);
+    get_value ("EMAIL", config_options.email, 0);
+    get_value ("EXCLUDE", config_options.exclude_paths, 0);
+    get_value ("IGNORE_DIRS", config_options.ignore_dirs, 0);
+    get_value ("LOG_FILE", config_options.log_file, 1);
+    get_value ("MAIL_PROG", config_options.mail_prog, 0);
+    get_value ("EXTRA_LIST", config_options.extra_list, 0);
+    get_value ("FORBIDDEN", config_options.forbidden_paths, 0);
 
-    check_return (get_value ("KEEP_LOGS", temp), "KEEP_LOGS", 0);
+    get_value ("KEEP_LOGS", temp, 0);
     config_options.keep_logs = atoi (temp);
 
-    check_return (get_value ("ALWAYS_NOTIFY", temp), "ALWAYS_NOTIFY", 0);
+    get_value ("ALWAYS_NOTIFY", temp, 0);
     if (isyes (temp))
 	config_options.flags |= FLAG_ANOT;
 
-    check_return (get_value ("ALWAYS_ROTATE", temp), "ALWAYS_ROTATE", 0);
+    get_value ("ALWAYS_ROTATE", temp, 0);
     if (isyes (temp))
 	config_options.flags |= FLAG_AROT;
 
-    check_return (get_value ("ENFORCE", temp), "ENFORCE", 0);
+    get_value ("ENFORCE", temp, 0);
     if (isyes (temp))
 	config_options.flags |= FLAG_EFOR;
 
-    check_return (get_value ("LISTALL", temp), "LISTALL", 0);
+    get_value ("LISTALL", temp, 0);
     if (isyes (temp))
 	config_options.flags |= FLAG_LALL;
 
